@@ -3,9 +3,9 @@ Main interface for codedeploy service type definitions.
 
 Usage::
 
-    from mypy_boto3.codedeploy.type_defs import AlarmTypeDef
+    from mypy_boto3.codedeploy.type_defs import AlarmConfigurationTypeDef
 
-    data: AlarmTypeDef = {...}
+    data: AlarmConfigurationTypeDef = {...}
 """
 from datetime import datetime
 import sys
@@ -22,59 +22,64 @@ else:
 
 
 __all__ = (
-    "AlarmTypeDef",
     "AlarmConfigurationTypeDef",
-    "AutoRollbackConfigurationTypeDef",
-    "GenericRevisionInfoTypeDef",
+    "AlarmTypeDef",
     "AppSpecContentTypeDef",
-    "GitHubLocationTypeDef",
-    "RawStringTypeDef",
-    "S3LocationTypeDef",
-    "RevisionLocationTypeDef",
-    "RevisionInfoTypeDef",
-    "BatchGetApplicationRevisionsOutputTypeDef",
     "ApplicationInfoTypeDef",
-    "BatchGetApplicationsOutputTypeDef",
+    "AutoRollbackConfigurationTypeDef",
     "AutoScalingGroupTypeDef",
-    "BlueInstanceTerminationOptionTypeDef",
-    "DeploymentReadyOptionTypeDef",
-    "GreenFleetProvisioningOptionTypeDef",
     "BlueGreenDeploymentConfigurationTypeDef",
+    "BlueInstanceTerminationOptionTypeDef",
+    "CloudFormationTargetTypeDef",
+    "DeploymentConfigInfoTypeDef",
+    "DeploymentGroupInfoTypeDef",
+    "DeploymentInfoTypeDef",
+    "DeploymentOverviewTypeDef",
+    "DeploymentReadyOptionTypeDef",
     "DeploymentStyleTypeDef",
+    "DeploymentTargetTypeDef",
+    "DiagnosticsTypeDef",
     "EC2TagFilterTypeDef",
     "EC2TagSetTypeDef",
     "ECSServiceTypeDef",
-    "LastDeploymentInfoTypeDef",
-    "ELBInfoTypeDef",
-    "TargetGroupInfoTypeDef",
-    "TrafficRouteTypeDef",
-    "TargetGroupPairInfoTypeDef",
-    "LoadBalancerInfoTypeDef",
-    "TagFilterTypeDef",
-    "OnPremisesTagSetTypeDef",
-    "TriggerConfigTypeDef",
-    "DeploymentGroupInfoTypeDef",
-    "BatchGetDeploymentGroupsOutputTypeDef",
-    "DiagnosticsTypeDef",
-    "LifecycleEventTypeDef",
-    "InstanceSummaryTypeDef",
-    "BatchGetDeploymentInstancesOutputTypeDef",
-    "CloudFormationTargetTypeDef",
-    "ECSTaskSetTypeDef",
     "ECSTargetTypeDef",
+    "ECSTaskSetTypeDef",
+    "ELBInfoTypeDef",
+    "ErrorInformationTypeDef",
+    "GenericRevisionInfoTypeDef",
+    "GitHubLocationTypeDef",
+    "GreenFleetProvisioningOptionTypeDef",
+    "InstanceInfoTypeDef",
+    "InstanceSummaryTypeDef",
     "InstanceTargetTypeDef",
     "LambdaFunctionInfoTypeDef",
     "LambdaTargetTypeDef",
-    "DeploymentTargetTypeDef",
-    "BatchGetDeploymentTargetsOutputTypeDef",
-    "DeploymentOverviewTypeDef",
-    "ErrorInformationTypeDef",
+    "LastDeploymentInfoTypeDef",
+    "LifecycleEventTypeDef",
+    "LoadBalancerInfoTypeDef",
+    "MinimumHealthyHostsTypeDef",
+    "OnPremisesTagSetTypeDef",
+    "RawStringTypeDef",
+    "RevisionInfoTypeDef",
+    "RevisionLocationTypeDef",
     "RollbackInfoTypeDef",
-    "TargetInstancesTypeDef",
-    "DeploymentInfoTypeDef",
-    "BatchGetDeploymentsOutputTypeDef",
+    "S3LocationTypeDef",
+    "TagFilterTypeDef",
     "TagTypeDef",
-    "InstanceInfoTypeDef",
+    "TargetGroupInfoTypeDef",
+    "TargetGroupPairInfoTypeDef",
+    "TargetInstancesTypeDef",
+    "TimeBasedCanaryTypeDef",
+    "TimeBasedLinearTypeDef",
+    "TrafficRouteTypeDef",
+    "TrafficRoutingConfigTypeDef",
+    "TriggerConfigTypeDef",
+    "BatchGetApplicationRevisionsOutputTypeDef",
+    "BatchGetApplicationsOutputTypeDef",
+    "BatchGetDeploymentGroupsOutputTypeDef",
+    "BatchGetDeploymentInstancesOutputTypeDef",
+    "BatchGetDeploymentTargetsOutputTypeDef",
+    "BatchGetDeploymentsOutputTypeDef",
     "BatchGetOnPremisesInstancesOutputTypeDef",
     "CreateApplicationOutputTypeDef",
     "CreateDeploymentConfigOutputTypeDef",
@@ -84,11 +89,6 @@ __all__ = (
     "DeleteGitHubAccountTokenOutputTypeDef",
     "GetApplicationOutputTypeDef",
     "GetApplicationRevisionOutputTypeDef",
-    "MinimumHealthyHostsTypeDef",
-    "TimeBasedCanaryTypeDef",
-    "TimeBasedLinearTypeDef",
-    "TrafficRoutingConfigTypeDef",
-    "DeploymentConfigInfoTypeDef",
     "GetDeploymentConfigOutputTypeDef",
     "GetDeploymentGroupOutputTypeDef",
     "GetDeploymentInstanceOutputTypeDef",
@@ -113,86 +113,18 @@ __all__ = (
     "WaiterConfigTypeDef",
 )
 
-AlarmTypeDef = TypedDict("AlarmTypeDef", {"name": str}, total=False)
-
 AlarmConfigurationTypeDef = TypedDict(
     "AlarmConfigurationTypeDef",
-    {"enabled": bool, "ignorePollAlarmFailure": bool, "alarms": List[AlarmTypeDef]},
+    {"enabled": bool, "ignorePollAlarmFailure": bool, "alarms": List["AlarmTypeDef"]},
     total=False,
 )
 
-AutoRollbackConfigurationTypeDef = TypedDict(
-    "AutoRollbackConfigurationTypeDef",
-    {
-        "enabled": bool,
-        "events": List[
-            Literal["DEPLOYMENT_FAILURE", "DEPLOYMENT_STOP_ON_ALARM", "DEPLOYMENT_STOP_ON_REQUEST"]
-        ],
-    },
-    total=False,
-)
-
-GenericRevisionInfoTypeDef = TypedDict(
-    "GenericRevisionInfoTypeDef",
-    {
-        "description": str,
-        "deploymentGroups": List[str],
-        "firstUsedTime": datetime,
-        "lastUsedTime": datetime,
-        "registerTime": datetime,
-    },
-    total=False,
-)
+AlarmTypeDef = TypedDict("AlarmTypeDef", {"name": str}, total=False)
 
 AppSpecContentTypeDef = TypedDict(
     "AppSpecContentTypeDef", {"content": str, "sha256": str}, total=False
 )
 
-GitHubLocationTypeDef = TypedDict(
-    "GitHubLocationTypeDef", {"repository": str, "commitId": str}, total=False
-)
-
-RawStringTypeDef = TypedDict("RawStringTypeDef", {"content": str, "sha256": str}, total=False)
-
-S3LocationTypeDef = TypedDict(
-    "S3LocationTypeDef",
-    {
-        "bucket": str,
-        "key": str,
-        "bundleType": Literal["tar", "tgz", "zip", "YAML", "JSON"],
-        "version": str,
-        "eTag": str,
-    },
-    total=False,
-)
-
-RevisionLocationTypeDef = TypedDict(
-    "RevisionLocationTypeDef",
-    {
-        "revisionType": Literal["S3", "GitHub", "String", "AppSpecContent"],
-        "s3Location": S3LocationTypeDef,
-        "gitHubLocation": GitHubLocationTypeDef,
-        "string": RawStringTypeDef,
-        "appSpecContent": AppSpecContentTypeDef,
-    },
-    total=False,
-)
-
-RevisionInfoTypeDef = TypedDict(
-    "RevisionInfoTypeDef",
-    {
-        "revisionLocation": RevisionLocationTypeDef,
-        "genericRevisionInfo": GenericRevisionInfoTypeDef,
-    },
-    total=False,
-)
-
-BatchGetApplicationRevisionsOutputTypeDef = TypedDict(
-    "BatchGetApplicationRevisionsOutputTypeDef",
-    {"applicationName": str, "errorMessage": str, "revisions": List[RevisionInfoTypeDef]},
-    total=False,
-)
-
 ApplicationInfoTypeDef = TypedDict(
     "ApplicationInfoTypeDef",
     {
@@ -206,9 +138,14 @@ ApplicationInfoTypeDef = TypedDict(
     total=False,
 )
 
-BatchGetApplicationsOutputTypeDef = TypedDict(
-    "BatchGetApplicationsOutputTypeDef",
-    {"applicationsInfo": List[ApplicationInfoTypeDef]},
+AutoRollbackConfigurationTypeDef = TypedDict(
+    "AutoRollbackConfigurationTypeDef",
+    {
+        "enabled": bool,
+        "events": List[
+            Literal["DEPLOYMENT_FAILURE", "DEPLOYMENT_STOP_ON_ALARM", "DEPLOYMENT_STOP_ON_REQUEST"]
+        ],
+    },
     total=False,
 )
 
@@ -216,12 +153,136 @@ AutoScalingGroupTypeDef = TypedDict(
     "AutoScalingGroupTypeDef", {"name": str, "hook": str}, total=False
 )
 
+BlueGreenDeploymentConfigurationTypeDef = TypedDict(
+    "BlueGreenDeploymentConfigurationTypeDef",
+    {
+        "terminateBlueInstancesOnDeploymentSuccess": "BlueInstanceTerminationOptionTypeDef",
+        "deploymentReadyOption": "DeploymentReadyOptionTypeDef",
+        "greenFleetProvisioningOption": "GreenFleetProvisioningOptionTypeDef",
+    },
+    total=False,
+)
+
 BlueInstanceTerminationOptionTypeDef = TypedDict(
     "BlueInstanceTerminationOptionTypeDef",
     {"action": Literal["TERMINATE", "KEEP_ALIVE"], "terminationWaitTimeInMinutes": int},
     total=False,
 )
 
+CloudFormationTargetTypeDef = TypedDict(
+    "CloudFormationTargetTypeDef",
+    {
+        "deploymentId": str,
+        "targetId": str,
+        "lastUpdatedAt": datetime,
+        "lifecycleEvents": List["LifecycleEventTypeDef"],
+        "status": Literal[
+            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
+        ],
+        "resourceType": str,
+        "targetVersionWeight": float,
+    },
+    total=False,
+)
+
+DeploymentConfigInfoTypeDef = TypedDict(
+    "DeploymentConfigInfoTypeDef",
+    {
+        "deploymentConfigId": str,
+        "deploymentConfigName": str,
+        "minimumHealthyHosts": "MinimumHealthyHostsTypeDef",
+        "createTime": datetime,
+        "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "trafficRoutingConfig": "TrafficRoutingConfigTypeDef",
+    },
+    total=False,
+)
+
+DeploymentGroupInfoTypeDef = TypedDict(
+    "DeploymentGroupInfoTypeDef",
+    {
+        "applicationName": str,
+        "deploymentGroupId": str,
+        "deploymentGroupName": str,
+        "deploymentConfigName": str,
+        "ec2TagFilters": List["EC2TagFilterTypeDef"],
+        "onPremisesInstanceTagFilters": List["TagFilterTypeDef"],
+        "autoScalingGroups": List["AutoScalingGroupTypeDef"],
+        "serviceRoleArn": str,
+        "targetRevision": "RevisionLocationTypeDef",
+        "triggerConfigurations": List["TriggerConfigTypeDef"],
+        "alarmConfiguration": "AlarmConfigurationTypeDef",
+        "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
+        "deploymentStyle": "DeploymentStyleTypeDef",
+        "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
+        "loadBalancerInfo": "LoadBalancerInfoTypeDef",
+        "lastSuccessfulDeployment": "LastDeploymentInfoTypeDef",
+        "lastAttemptedDeployment": "LastDeploymentInfoTypeDef",
+        "ec2TagSet": "EC2TagSetTypeDef",
+        "onPremisesTagSet": "OnPremisesTagSetTypeDef",
+        "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "ecsServices": List["ECSServiceTypeDef"],
+    },
+    total=False,
+)
+
+DeploymentInfoTypeDef = TypedDict(
+    "DeploymentInfoTypeDef",
+    {
+        "applicationName": str,
+        "deploymentGroupName": str,
+        "deploymentConfigName": str,
+        "deploymentId": str,
+        "previousRevision": "RevisionLocationTypeDef",
+        "revision": "RevisionLocationTypeDef",
+        "status": Literal[
+            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
+        ],
+        "errorInformation": "ErrorInformationTypeDef",
+        "createTime": datetime,
+        "startTime": datetime,
+        "completeTime": datetime,
+        "deploymentOverview": "DeploymentOverviewTypeDef",
+        "description": str,
+        "creator": Literal[
+            "user",
+            "autoscaling",
+            "codeDeployRollback",
+            "CodeDeploy",
+            "CloudFormation",
+            "CloudFormationRollback",
+        ],
+        "ignoreApplicationStopFailures": bool,
+        "autoRollbackConfiguration": "AutoRollbackConfigurationTypeDef",
+        "updateOutdatedInstancesOnly": bool,
+        "rollbackInfo": "RollbackInfoTypeDef",
+        "deploymentStyle": "DeploymentStyleTypeDef",
+        "targetInstances": "TargetInstancesTypeDef",
+        "instanceTerminationWaitTimeStarted": bool,
+        "blueGreenDeploymentConfiguration": "BlueGreenDeploymentConfigurationTypeDef",
+        "loadBalancerInfo": "LoadBalancerInfoTypeDef",
+        "additionalDeploymentStatusInfo": str,
+        "fileExistsBehavior": Literal["DISALLOW", "OVERWRITE", "RETAIN"],
+        "deploymentStatusMessages": List[str],
+        "computePlatform": Literal["Server", "Lambda", "ECS"],
+        "externalId": str,
+    },
+    total=False,
+)
+
+DeploymentOverviewTypeDef = TypedDict(
+    "DeploymentOverviewTypeDef",
+    {
+        "Pending": int,
+        "InProgress": int,
+        "Succeeded": int,
+        "Failed": int,
+        "Skipped": int,
+        "Ready": int,
+    },
+    total=False,
+)
+
 DeploymentReadyOptionTypeDef = TypedDict(
     "DeploymentReadyOptionTypeDef",
     {
@@ -231,22 +292,6 @@ DeploymentReadyOptionTypeDef = TypedDict(
     total=False,
 )
 
-GreenFleetProvisioningOptionTypeDef = TypedDict(
-    "GreenFleetProvisioningOptionTypeDef",
-    {"action": Literal["DISCOVER_EXISTING", "COPY_AUTO_SCALING_GROUP"]},
-    total=False,
-)
-
-BlueGreenDeploymentConfigurationTypeDef = TypedDict(
-    "BlueGreenDeploymentConfigurationTypeDef",
-    {
-        "terminateBlueInstancesOnDeploymentSuccess": BlueInstanceTerminationOptionTypeDef,
-        "deploymentReadyOption": DeploymentReadyOptionTypeDef,
-        "greenFleetProvisioningOption": GreenFleetProvisioningOptionTypeDef,
-    },
-    total=False,
-)
-
 DeploymentStyleTypeDef = TypedDict(
     "DeploymentStyleTypeDef",
     {
@@ -256,126 +301,20 @@ DeploymentStyleTypeDef = TypedDict(
     total=False,
 )
 
-EC2TagFilterTypeDef = TypedDict(
-    "EC2TagFilterTypeDef",
-    {"Key": str, "Value": str, "Type": Literal["KEY_ONLY", "VALUE_ONLY", "KEY_AND_VALUE"]},
-    total=False,
-)
-
-EC2TagSetTypeDef = TypedDict(
-    "EC2TagSetTypeDef", {"ec2TagSetList": List[List[EC2TagFilterTypeDef]]}, total=False
-)
-
-ECSServiceTypeDef = TypedDict(
-    "ECSServiceTypeDef", {"serviceName": str, "clusterName": str}, total=False
-)
-
-LastDeploymentInfoTypeDef = TypedDict(
-    "LastDeploymentInfoTypeDef",
+DeploymentTargetTypeDef = TypedDict(
+    "DeploymentTargetTypeDef",
     {
-        "deploymentId": str,
-        "status": Literal[
-            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
+        "deploymentTargetType": Literal[
+            "InstanceTarget", "LambdaTarget", "ECSTarget", "CloudFormationTarget"
         ],
-        "endTime": datetime,
-        "createTime": datetime,
+        "instanceTarget": "InstanceTargetTypeDef",
+        "lambdaTarget": "LambdaTargetTypeDef",
+        "ecsTarget": "ECSTargetTypeDef",
+        "cloudFormationTarget": "CloudFormationTargetTypeDef",
     },
     total=False,
 )
 
-ELBInfoTypeDef = TypedDict("ELBInfoTypeDef", {"name": str}, total=False)
-
-TargetGroupInfoTypeDef = TypedDict("TargetGroupInfoTypeDef", {"name": str}, total=False)
-
-TrafficRouteTypeDef = TypedDict("TrafficRouteTypeDef", {"listenerArns": List[str]}, total=False)
-
-TargetGroupPairInfoTypeDef = TypedDict(
-    "TargetGroupPairInfoTypeDef",
-    {
-        "targetGroups": List[TargetGroupInfoTypeDef],
-        "prodTrafficRoute": TrafficRouteTypeDef,
-        "testTrafficRoute": TrafficRouteTypeDef,
-    },
-    total=False,
-)
-
-LoadBalancerInfoTypeDef = TypedDict(
-    "LoadBalancerInfoTypeDef",
-    {
-        "elbInfoList": List[ELBInfoTypeDef],
-        "targetGroupInfoList": List[TargetGroupInfoTypeDef],
-        "targetGroupPairInfoList": List[TargetGroupPairInfoTypeDef],
-    },
-    total=False,
-)
-
-TagFilterTypeDef = TypedDict(
-    "TagFilterTypeDef",
-    {"Key": str, "Value": str, "Type": Literal["KEY_ONLY", "VALUE_ONLY", "KEY_AND_VALUE"]},
-    total=False,
-)
-
-OnPremisesTagSetTypeDef = TypedDict(
-    "OnPremisesTagSetTypeDef", {"onPremisesTagSetList": List[List[TagFilterTypeDef]]}, total=False
-)
-
-TriggerConfigTypeDef = TypedDict(
-    "TriggerConfigTypeDef",
-    {
-        "triggerName": str,
-        "triggerTargetArn": str,
-        "triggerEvents": List[
-            Literal[
-                "DeploymentStart",
-                "DeploymentSuccess",
-                "DeploymentFailure",
-                "DeploymentStop",
-                "DeploymentRollback",
-                "DeploymentReady",
-                "InstanceStart",
-                "InstanceSuccess",
-                "InstanceFailure",
-                "InstanceReady",
-            ]
-        ],
-    },
-    total=False,
-)
-
-DeploymentGroupInfoTypeDef = TypedDict(
-    "DeploymentGroupInfoTypeDef",
-    {
-        "applicationName": str,
-        "deploymentGroupId": str,
-        "deploymentGroupName": str,
-        "deploymentConfigName": str,
-        "ec2TagFilters": List[EC2TagFilterTypeDef],
-        "onPremisesInstanceTagFilters": List[TagFilterTypeDef],
-        "autoScalingGroups": List[AutoScalingGroupTypeDef],
-        "serviceRoleArn": str,
-        "targetRevision": RevisionLocationTypeDef,
-        "triggerConfigurations": List[TriggerConfigTypeDef],
-        "alarmConfiguration": AlarmConfigurationTypeDef,
-        "autoRollbackConfiguration": AutoRollbackConfigurationTypeDef,
-        "deploymentStyle": DeploymentStyleTypeDef,
-        "blueGreenDeploymentConfiguration": BlueGreenDeploymentConfigurationTypeDef,
-        "loadBalancerInfo": LoadBalancerInfoTypeDef,
-        "lastSuccessfulDeployment": LastDeploymentInfoTypeDef,
-        "lastAttemptedDeployment": LastDeploymentInfoTypeDef,
-        "ec2TagSet": EC2TagSetTypeDef,
-        "onPremisesTagSet": OnPremisesTagSetTypeDef,
-        "computePlatform": Literal["Server", "Lambda", "ECS"],
-        "ecsServices": List[ECSServiceTypeDef],
-    },
-    total=False,
-)
-
-BatchGetDeploymentGroupsOutputTypeDef = TypedDict(
-    "BatchGetDeploymentGroupsOutputTypeDef",
-    {"deploymentGroupsInfo": List[DeploymentGroupInfoTypeDef], "errorMessage": str},
-    total=False,
-)
-
 DiagnosticsTypeDef = TypedDict(
     "DiagnosticsTypeDef",
     {
@@ -394,51 +333,32 @@ DiagnosticsTypeDef = TypedDict(
     total=False,
 )
 
-LifecycleEventTypeDef = TypedDict(
-    "LifecycleEventTypeDef",
-    {
-        "lifecycleEventName": str,
-        "diagnostics": DiagnosticsTypeDef,
-        "startTime": datetime,
-        "endTime": datetime,
-        "status": Literal["Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown"],
-    },
+EC2TagFilterTypeDef = TypedDict(
+    "EC2TagFilterTypeDef",
+    {"Key": str, "Value": str, "Type": Literal["KEY_ONLY", "VALUE_ONLY", "KEY_AND_VALUE"]},
     total=False,
 )
 
-InstanceSummaryTypeDef = TypedDict(
-    "InstanceSummaryTypeDef",
-    {
-        "deploymentId": str,
-        "instanceId": str,
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
-        "lastUpdatedAt": datetime,
-        "lifecycleEvents": List[LifecycleEventTypeDef],
-        "instanceType": Literal["Blue", "Green"],
-    },
-    total=False,
+EC2TagSetTypeDef = TypedDict(
+    "EC2TagSetTypeDef", {"ec2TagSetList": List[List["EC2TagFilterTypeDef"]]}, total=False
 )
 
-BatchGetDeploymentInstancesOutputTypeDef = TypedDict(
-    "BatchGetDeploymentInstancesOutputTypeDef",
-    {"instancesSummary": List[InstanceSummaryTypeDef], "errorMessage": str},
-    total=False,
+ECSServiceTypeDef = TypedDict(
+    "ECSServiceTypeDef", {"serviceName": str, "clusterName": str}, total=False
 )
 
-CloudFormationTargetTypeDef = TypedDict(
-    "CloudFormationTargetTypeDef",
+ECSTargetTypeDef = TypedDict(
+    "ECSTargetTypeDef",
     {
         "deploymentId": str,
         "targetId": str,
+        "targetArn": str,
         "lastUpdatedAt": datetime,
-        "lifecycleEvents": List[LifecycleEventTypeDef],
+        "lifecycleEvents": List["LifecycleEventTypeDef"],
         "status": Literal[
             "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
         ],
-        "resourceType": str,
-        "targetVersionWeight": float,
+        "taskSetsInfo": List["ECSTaskSetTypeDef"],
     },
     total=False,
 )
@@ -452,104 +372,13 @@ ECSTaskSetTypeDef = TypedDict(
         "runningCount": int,
         "status": str,
         "trafficWeight": float,
-        "targetGroup": TargetGroupInfoTypeDef,
+        "targetGroup": "TargetGroupInfoTypeDef",
         "taskSetLabel": Literal["Blue", "Green"],
     },
     total=False,
 )
 
-ECSTargetTypeDef = TypedDict(
-    "ECSTargetTypeDef",
-    {
-        "deploymentId": str,
-        "targetId": str,
-        "targetArn": str,
-        "lastUpdatedAt": datetime,
-        "lifecycleEvents": List[LifecycleEventTypeDef],
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
-        "taskSetsInfo": List[ECSTaskSetTypeDef],
-    },
-    total=False,
-)
-
-InstanceTargetTypeDef = TypedDict(
-    "InstanceTargetTypeDef",
-    {
-        "deploymentId": str,
-        "targetId": str,
-        "targetArn": str,
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
-        "lastUpdatedAt": datetime,
-        "lifecycleEvents": List[LifecycleEventTypeDef],
-        "instanceLabel": Literal["Blue", "Green"],
-    },
-    total=False,
-)
-
-LambdaFunctionInfoTypeDef = TypedDict(
-    "LambdaFunctionInfoTypeDef",
-    {
-        "functionName": str,
-        "functionAlias": str,
-        "currentVersion": str,
-        "targetVersion": str,
-        "targetVersionWeight": float,
-    },
-    total=False,
-)
-
-LambdaTargetTypeDef = TypedDict(
-    "LambdaTargetTypeDef",
-    {
-        "deploymentId": str,
-        "targetId": str,
-        "targetArn": str,
-        "status": Literal[
-            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
-        ],
-        "lastUpdatedAt": datetime,
-        "lifecycleEvents": List[LifecycleEventTypeDef],
-        "lambdaFunctionInfo": LambdaFunctionInfoTypeDef,
-    },
-    total=False,
-)
-
-DeploymentTargetTypeDef = TypedDict(
-    "DeploymentTargetTypeDef",
-    {
-        "deploymentTargetType": Literal[
-            "InstanceTarget", "LambdaTarget", "ECSTarget", "CloudFormationTarget"
-        ],
-        "instanceTarget": InstanceTargetTypeDef,
-        "lambdaTarget": LambdaTargetTypeDef,
-        "ecsTarget": ECSTargetTypeDef,
-        "cloudFormationTarget": CloudFormationTargetTypeDef,
-    },
-    total=False,
-)
-
-BatchGetDeploymentTargetsOutputTypeDef = TypedDict(
-    "BatchGetDeploymentTargetsOutputTypeDef",
-    {"deploymentTargets": List[DeploymentTargetTypeDef]},
-    total=False,
-)
-
-DeploymentOverviewTypeDef = TypedDict(
-    "DeploymentOverviewTypeDef",
-    {
-        "Pending": int,
-        "InProgress": int,
-        "Succeeded": int,
-        "Failed": int,
-        "Skipped": int,
-        "Ready": int,
-    },
-    total=False,
-)
+ELBInfoTypeDef = TypedDict("ELBInfoTypeDef", {"name": str}, total=False)
 
 ErrorInformationTypeDef = TypedDict(
     "ErrorInformationTypeDef",
@@ -595,73 +424,27 @@ ErrorInformationTypeDef = TypedDict(
     total=False,
 )
 
-RollbackInfoTypeDef = TypedDict(
-    "RollbackInfoTypeDef",
-    {"rollbackDeploymentId": str, "rollbackTriggeringDeploymentId": str, "rollbackMessage": str},
-    total=False,
-)
-
-TargetInstancesTypeDef = TypedDict(
-    "TargetInstancesTypeDef",
+GenericRevisionInfoTypeDef = TypedDict(
+    "GenericRevisionInfoTypeDef",
     {
-        "tagFilters": List[EC2TagFilterTypeDef],
-        "autoScalingGroups": List[str],
-        "ec2TagSet": EC2TagSetTypeDef,
-    },
-    total=False,
-)
-
-DeploymentInfoTypeDef = TypedDict(
-    "DeploymentInfoTypeDef",
-    {
-        "applicationName": str,
-        "deploymentGroupName": str,
-        "deploymentConfigName": str,
-        "deploymentId": str,
-        "previousRevision": RevisionLocationTypeDef,
-        "revision": RevisionLocationTypeDef,
-        "status": Literal[
-            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
-        ],
-        "errorInformation": ErrorInformationTypeDef,
-        "createTime": datetime,
-        "startTime": datetime,
-        "completeTime": datetime,
-        "deploymentOverview": DeploymentOverviewTypeDef,
         "description": str,
-        "creator": Literal[
-            "user",
-            "autoscaling",
-            "codeDeployRollback",
-            "CodeDeploy",
-            "CloudFormation",
-            "CloudFormationRollback",
-        ],
-        "ignoreApplicationStopFailures": bool,
-        "autoRollbackConfiguration": AutoRollbackConfigurationTypeDef,
-        "updateOutdatedInstancesOnly": bool,
-        "rollbackInfo": RollbackInfoTypeDef,
-        "deploymentStyle": DeploymentStyleTypeDef,
-        "targetInstances": TargetInstancesTypeDef,
-        "instanceTerminationWaitTimeStarted": bool,
-        "blueGreenDeploymentConfiguration": BlueGreenDeploymentConfigurationTypeDef,
-        "loadBalancerInfo": LoadBalancerInfoTypeDef,
-        "additionalDeploymentStatusInfo": str,
-        "fileExistsBehavior": Literal["DISALLOW", "OVERWRITE", "RETAIN"],
-        "deploymentStatusMessages": List[str],
-        "computePlatform": Literal["Server", "Lambda", "ECS"],
-        "externalId": str,
+        "deploymentGroups": List[str],
+        "firstUsedTime": datetime,
+        "lastUsedTime": datetime,
+        "registerTime": datetime,
     },
     total=False,
 )
 
-BatchGetDeploymentsOutputTypeDef = TypedDict(
-    "BatchGetDeploymentsOutputTypeDef",
-    {"deploymentsInfo": List[DeploymentInfoTypeDef]},
-    total=False,
+GitHubLocationTypeDef = TypedDict(
+    "GitHubLocationTypeDef", {"repository": str, "commitId": str}, total=False
 )
 
-TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+GreenFleetProvisioningOptionTypeDef = TypedDict(
+    "GreenFleetProvisioningOptionTypeDef",
+    {"action": Literal["DISCOVER_EXISTING", "COPY_AUTO_SCALING_GROUP"]},
+    total=False,
+)
 
 InstanceInfoTypeDef = TypedDict(
     "InstanceInfoTypeDef",
@@ -672,14 +455,268 @@ InstanceInfoTypeDef = TypedDict(
         "instanceArn": str,
         "registerTime": datetime,
         "deregisterTime": datetime,
-        "tags": List[TagTypeDef],
+        "tags": List["TagTypeDef"],
     },
     total=False,
 )
 
+InstanceSummaryTypeDef = TypedDict(
+    "InstanceSummaryTypeDef",
+    {
+        "deploymentId": str,
+        "instanceId": str,
+        "status": Literal[
+            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
+        ],
+        "lastUpdatedAt": datetime,
+        "lifecycleEvents": List["LifecycleEventTypeDef"],
+        "instanceType": Literal["Blue", "Green"],
+    },
+    total=False,
+)
+
+InstanceTargetTypeDef = TypedDict(
+    "InstanceTargetTypeDef",
+    {
+        "deploymentId": str,
+        "targetId": str,
+        "targetArn": str,
+        "status": Literal[
+            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
+        ],
+        "lastUpdatedAt": datetime,
+        "lifecycleEvents": List["LifecycleEventTypeDef"],
+        "instanceLabel": Literal["Blue", "Green"],
+    },
+    total=False,
+)
+
+LambdaFunctionInfoTypeDef = TypedDict(
+    "LambdaFunctionInfoTypeDef",
+    {
+        "functionName": str,
+        "functionAlias": str,
+        "currentVersion": str,
+        "targetVersion": str,
+        "targetVersionWeight": float,
+    },
+    total=False,
+)
+
+LambdaTargetTypeDef = TypedDict(
+    "LambdaTargetTypeDef",
+    {
+        "deploymentId": str,
+        "targetId": str,
+        "targetArn": str,
+        "status": Literal[
+            "Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown", "Ready"
+        ],
+        "lastUpdatedAt": datetime,
+        "lifecycleEvents": List["LifecycleEventTypeDef"],
+        "lambdaFunctionInfo": "LambdaFunctionInfoTypeDef",
+    },
+    total=False,
+)
+
+LastDeploymentInfoTypeDef = TypedDict(
+    "LastDeploymentInfoTypeDef",
+    {
+        "deploymentId": str,
+        "status": Literal[
+            "Created", "Queued", "InProgress", "Baking", "Succeeded", "Failed", "Stopped", "Ready"
+        ],
+        "endTime": datetime,
+        "createTime": datetime,
+    },
+    total=False,
+)
+
+LifecycleEventTypeDef = TypedDict(
+    "LifecycleEventTypeDef",
+    {
+        "lifecycleEventName": str,
+        "diagnostics": "DiagnosticsTypeDef",
+        "startTime": datetime,
+        "endTime": datetime,
+        "status": Literal["Pending", "InProgress", "Succeeded", "Failed", "Skipped", "Unknown"],
+    },
+    total=False,
+)
+
+LoadBalancerInfoTypeDef = TypedDict(
+    "LoadBalancerInfoTypeDef",
+    {
+        "elbInfoList": List["ELBInfoTypeDef"],
+        "targetGroupInfoList": List["TargetGroupInfoTypeDef"],
+        "targetGroupPairInfoList": List["TargetGroupPairInfoTypeDef"],
+    },
+    total=False,
+)
+
+MinimumHealthyHostsTypeDef = TypedDict(
+    "MinimumHealthyHostsTypeDef",
+    {"value": int, "type": Literal["HOST_COUNT", "FLEET_PERCENT"]},
+    total=False,
+)
+
+OnPremisesTagSetTypeDef = TypedDict(
+    "OnPremisesTagSetTypeDef", {"onPremisesTagSetList": List[List["TagFilterTypeDef"]]}, total=False
+)
+
+RawStringTypeDef = TypedDict("RawStringTypeDef", {"content": str, "sha256": str}, total=False)
+
+RevisionInfoTypeDef = TypedDict(
+    "RevisionInfoTypeDef",
+    {
+        "revisionLocation": "RevisionLocationTypeDef",
+        "genericRevisionInfo": "GenericRevisionInfoTypeDef",
+    },
+    total=False,
+)
+
+RevisionLocationTypeDef = TypedDict(
+    "RevisionLocationTypeDef",
+    {
+        "revisionType": Literal["S3", "GitHub", "String", "AppSpecContent"],
+        "s3Location": "S3LocationTypeDef",
+        "gitHubLocation": "GitHubLocationTypeDef",
+        "string": "RawStringTypeDef",
+        "appSpecContent": "AppSpecContentTypeDef",
+    },
+    total=False,
+)
+
+RollbackInfoTypeDef = TypedDict(
+    "RollbackInfoTypeDef",
+    {"rollbackDeploymentId": str, "rollbackTriggeringDeploymentId": str, "rollbackMessage": str},
+    total=False,
+)
+
+S3LocationTypeDef = TypedDict(
+    "S3LocationTypeDef",
+    {
+        "bucket": str,
+        "key": str,
+        "bundleType": Literal["tar", "tgz", "zip", "YAML", "JSON"],
+        "version": str,
+        "eTag": str,
+    },
+    total=False,
+)
+
+TagFilterTypeDef = TypedDict(
+    "TagFilterTypeDef",
+    {"Key": str, "Value": str, "Type": Literal["KEY_ONLY", "VALUE_ONLY", "KEY_AND_VALUE"]},
+    total=False,
+)
+
+TagTypeDef = TypedDict("TagTypeDef", {"Key": str, "Value": str}, total=False)
+
+TargetGroupInfoTypeDef = TypedDict("TargetGroupInfoTypeDef", {"name": str}, total=False)
+
+TargetGroupPairInfoTypeDef = TypedDict(
+    "TargetGroupPairInfoTypeDef",
+    {
+        "targetGroups": List["TargetGroupInfoTypeDef"],
+        "prodTrafficRoute": "TrafficRouteTypeDef",
+        "testTrafficRoute": "TrafficRouteTypeDef",
+    },
+    total=False,
+)
+
+TargetInstancesTypeDef = TypedDict(
+    "TargetInstancesTypeDef",
+    {
+        "tagFilters": List["EC2TagFilterTypeDef"],
+        "autoScalingGroups": List[str],
+        "ec2TagSet": "EC2TagSetTypeDef",
+    },
+    total=False,
+)
+
+TimeBasedCanaryTypeDef = TypedDict(
+    "TimeBasedCanaryTypeDef", {"canaryPercentage": int, "canaryInterval": int}, total=False
+)
+
+TimeBasedLinearTypeDef = TypedDict(
+    "TimeBasedLinearTypeDef", {"linearPercentage": int, "linearInterval": int}, total=False
+)
+
+TrafficRouteTypeDef = TypedDict("TrafficRouteTypeDef", {"listenerArns": List[str]}, total=False)
+
+TrafficRoutingConfigTypeDef = TypedDict(
+    "TrafficRoutingConfigTypeDef",
+    {
+        "type": Literal["TimeBasedCanary", "TimeBasedLinear", "AllAtOnce"],
+        "timeBasedCanary": "TimeBasedCanaryTypeDef",
+        "timeBasedLinear": "TimeBasedLinearTypeDef",
+    },
+    total=False,
+)
+
+TriggerConfigTypeDef = TypedDict(
+    "TriggerConfigTypeDef",
+    {
+        "triggerName": str,
+        "triggerTargetArn": str,
+        "triggerEvents": List[
+            Literal[
+                "DeploymentStart",
+                "DeploymentSuccess",
+                "DeploymentFailure",
+                "DeploymentStop",
+                "DeploymentRollback",
+                "DeploymentReady",
+                "InstanceStart",
+                "InstanceSuccess",
+                "InstanceFailure",
+                "InstanceReady",
+            ]
+        ],
+    },
+    total=False,
+)
+
+BatchGetApplicationRevisionsOutputTypeDef = TypedDict(
+    "BatchGetApplicationRevisionsOutputTypeDef",
+    {"applicationName": str, "errorMessage": str, "revisions": List["RevisionInfoTypeDef"]},
+    total=False,
+)
+
+BatchGetApplicationsOutputTypeDef = TypedDict(
+    "BatchGetApplicationsOutputTypeDef",
+    {"applicationsInfo": List["ApplicationInfoTypeDef"]},
+    total=False,
+)
+
+BatchGetDeploymentGroupsOutputTypeDef = TypedDict(
+    "BatchGetDeploymentGroupsOutputTypeDef",
+    {"deploymentGroupsInfo": List["DeploymentGroupInfoTypeDef"], "errorMessage": str},
+    total=False,
+)
+
+BatchGetDeploymentInstancesOutputTypeDef = TypedDict(
+    "BatchGetDeploymentInstancesOutputTypeDef",
+    {"instancesSummary": List["InstanceSummaryTypeDef"], "errorMessage": str},
+    total=False,
+)
+
+BatchGetDeploymentTargetsOutputTypeDef = TypedDict(
+    "BatchGetDeploymentTargetsOutputTypeDef",
+    {"deploymentTargets": List["DeploymentTargetTypeDef"]},
+    total=False,
+)
+
+BatchGetDeploymentsOutputTypeDef = TypedDict(
+    "BatchGetDeploymentsOutputTypeDef",
+    {"deploymentsInfo": List["DeploymentInfoTypeDef"]},
+    total=False,
+)
+
 BatchGetOnPremisesInstancesOutputTypeDef = TypedDict(
     "BatchGetOnPremisesInstancesOutputTypeDef",
-    {"instanceInfos": List[InstanceInfoTypeDef]},
+    {"instanceInfos": List["InstanceInfoTypeDef"]},
     total=False,
 )
 
@@ -701,7 +738,7 @@ CreateDeploymentOutputTypeDef = TypedDict(
 
 DeleteDeploymentGroupOutputTypeDef = TypedDict(
     "DeleteDeploymentGroupOutputTypeDef",
-    {"hooksNotCleanedUp": List[AutoScalingGroupTypeDef]},
+    {"hooksNotCleanedUp": List["AutoScalingGroupTypeDef"]},
     total=False,
 )
 
@@ -710,87 +747,50 @@ DeleteGitHubAccountTokenOutputTypeDef = TypedDict(
 )
 
 GetApplicationOutputTypeDef = TypedDict(
-    "GetApplicationOutputTypeDef", {"application": ApplicationInfoTypeDef}, total=False
+    "GetApplicationOutputTypeDef", {"application": "ApplicationInfoTypeDef"}, total=False
 )
 
 GetApplicationRevisionOutputTypeDef = TypedDict(
     "GetApplicationRevisionOutputTypeDef",
     {
         "applicationName": str,
-        "revision": RevisionLocationTypeDef,
-        "revisionInfo": GenericRevisionInfoTypeDef,
-    },
-    total=False,
-)
-
-MinimumHealthyHostsTypeDef = TypedDict(
-    "MinimumHealthyHostsTypeDef",
-    {"value": int, "type": Literal["HOST_COUNT", "FLEET_PERCENT"]},
-    total=False,
-)
-
-TimeBasedCanaryTypeDef = TypedDict(
-    "TimeBasedCanaryTypeDef", {"canaryPercentage": int, "canaryInterval": int}, total=False
-)
-
-TimeBasedLinearTypeDef = TypedDict(
-    "TimeBasedLinearTypeDef", {"linearPercentage": int, "linearInterval": int}, total=False
-)
-
-TrafficRoutingConfigTypeDef = TypedDict(
-    "TrafficRoutingConfigTypeDef",
-    {
-        "type": Literal["TimeBasedCanary", "TimeBasedLinear", "AllAtOnce"],
-        "timeBasedCanary": TimeBasedCanaryTypeDef,
-        "timeBasedLinear": TimeBasedLinearTypeDef,
-    },
-    total=False,
-)
-
-DeploymentConfigInfoTypeDef = TypedDict(
-    "DeploymentConfigInfoTypeDef",
-    {
-        "deploymentConfigId": str,
-        "deploymentConfigName": str,
-        "minimumHealthyHosts": MinimumHealthyHostsTypeDef,
-        "createTime": datetime,
-        "computePlatform": Literal["Server", "Lambda", "ECS"],
-        "trafficRoutingConfig": TrafficRoutingConfigTypeDef,
+        "revision": "RevisionLocationTypeDef",
+        "revisionInfo": "GenericRevisionInfoTypeDef",
     },
     total=False,
 )
 
 GetDeploymentConfigOutputTypeDef = TypedDict(
     "GetDeploymentConfigOutputTypeDef",
-    {"deploymentConfigInfo": DeploymentConfigInfoTypeDef},
+    {"deploymentConfigInfo": "DeploymentConfigInfoTypeDef"},
     total=False,
 )
 
 GetDeploymentGroupOutputTypeDef = TypedDict(
     "GetDeploymentGroupOutputTypeDef",
-    {"deploymentGroupInfo": DeploymentGroupInfoTypeDef},
+    {"deploymentGroupInfo": "DeploymentGroupInfoTypeDef"},
     total=False,
 )
 
 GetDeploymentInstanceOutputTypeDef = TypedDict(
-    "GetDeploymentInstanceOutputTypeDef", {"instanceSummary": InstanceSummaryTypeDef}, total=False
+    "GetDeploymentInstanceOutputTypeDef", {"instanceSummary": "InstanceSummaryTypeDef"}, total=False
 )
 
 GetDeploymentOutputTypeDef = TypedDict(
-    "GetDeploymentOutputTypeDef", {"deploymentInfo": DeploymentInfoTypeDef}, total=False
+    "GetDeploymentOutputTypeDef", {"deploymentInfo": "DeploymentInfoTypeDef"}, total=False
 )
 
 GetDeploymentTargetOutputTypeDef = TypedDict(
-    "GetDeploymentTargetOutputTypeDef", {"deploymentTarget": DeploymentTargetTypeDef}, total=False
+    "GetDeploymentTargetOutputTypeDef", {"deploymentTarget": "DeploymentTargetTypeDef"}, total=False
 )
 
 GetOnPremisesInstanceOutputTypeDef = TypedDict(
-    "GetOnPremisesInstanceOutputTypeDef", {"instanceInfo": InstanceInfoTypeDef}, total=False
+    "GetOnPremisesInstanceOutputTypeDef", {"instanceInfo": "InstanceInfoTypeDef"}, total=False
 )
 
 ListApplicationRevisionsOutputTypeDef = TypedDict(
     "ListApplicationRevisionsOutputTypeDef",
-    {"revisions": List[RevisionLocationTypeDef], "nextToken": str},
+    {"revisions": List["RevisionLocationTypeDef"], "nextToken": str},
     total=False,
 )
 
@@ -837,7 +837,7 @@ ListOnPremisesInstancesOutputTypeDef = TypedDict(
 )
 
 ListTagsForResourceOutputTypeDef = TypedDict(
-    "ListTagsForResourceOutputTypeDef", {"Tags": List[TagTypeDef], "NextToken": str}, total=False
+    "ListTagsForResourceOutputTypeDef", {"Tags": List["TagTypeDef"], "NextToken": str}, total=False
 )
 
 PaginatorConfigTypeDef = TypedDict(
@@ -860,7 +860,7 @@ TimeRangeTypeDef = TypedDict("TimeRangeTypeDef", {"start": datetime, "end": date
 
 UpdateDeploymentGroupOutputTypeDef = TypedDict(
     "UpdateDeploymentGroupOutputTypeDef",
-    {"hooksNotCleanedUp": List[AutoScalingGroupTypeDef]},
+    {"hooksNotCleanedUp": List["AutoScalingGroupTypeDef"]},
     total=False,
 )
 
